@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.023_002'; # TRIAL VERSION
+our $VERSION = '0.023_003'; # TRIAL VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -322,6 +322,23 @@ sub EXISTS {
     my ($self, $i) = @_;
     return exists $self->{data}->[ $i ];
 }
+sub CLEAR {
+    my ($self) = @_;
+    $self->{data} = [];
+}
+sub SHIFT {
+    my ($self) = @_;
+    shift @{ $self->{data} };
+}
+sub UNSHIFT {
+    my ($self, @args) = @_;
+    unshift @{ $self->{data} }, @args;
+}
+sub SPLICE {
+    my ($self, $offset, $length, @args) = @_;
+    splice @{ $self->{data} }, $offset, $length, @args;
+}
+sub EXTEND {}
 
 
 package YAML::PP::Preserve::Scalar;
